@@ -30,7 +30,7 @@ class ITCServerParser(BaseParser):
 
 
     def parseSessionURLs(self, htmlTree):
-        manageAppsLink = htmlTree.xpath("//a[.='Manage your apps']")
+        manageAppsLink = htmlTree.xpath("//a[.='Manage Your Apps']")
         if len(manageAppsLink) == 0:
             raise
 
@@ -244,7 +244,7 @@ class ITCServerParser(BaseParser):
 
         for ratingTr in appRatingTable:
             inputs = ratingTr.xpath('.//input')
-            if len(inputs) != 3:
+            if len(inputs) < 2:
                 continue
             appRating = {'name': inputs[0].attrib['name'], 'ratings': []}
             for inpt in inputs:
